@@ -7,14 +7,14 @@ class MindsDBLexer(Lexer):
     ignore = ' \t\n\r'
 
     tokens = {
-        USE, DROP, CREATE,
+        USE, DROP, CREATE, DESCRIBE, RETRAIN,
 
         # Misc
         SET, AUTOCOMMIT, START, TRANSACTION, COMMIT, ROLLBACK, ALTER, EXPLAIN,
 
         # Mindsdb special
 
-        PREDICTOR, PREDICTORS, INTEGRATION, INTEGRATIONS,
+        PREDICTOR, PREDICTORS, DATASOURCE, INTEGRATION, INTEGRATIONS,
         STREAM, STREAMS, PUBLICATION, PUBLICATIONS, VIEW, VIEWS,
 
         LATEST, HORIZON, USING,
@@ -24,7 +24,7 @@ class MindsDBLexer(Lexer):
         # SHOW Keywords
 
         SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL, VARIABLES, SESSION, STATUS,
-        GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS, ENGINES, CHARSET, COLLATION,
+        GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS, ENGINES, CHARSET, COLLATION, PLUGINS,
 
 
         # SELECT Keywords
@@ -49,6 +49,7 @@ class MindsDBLexer(Lexer):
         # Data types
         CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE}
 
+    RETRAIN = r'\bRETRAIN\b'
     # Custom commands
 
     USE = r'\bUSE\b'
@@ -67,6 +68,7 @@ class MindsDBLexer(Lexer):
     STREAMS = r'\bSTREAMS\b'
     PREDICTOR = r'\bPREDICTOR\b'
     PREDICTORS = r'\bPREDICTORS\b'
+    DATASOURCE = r'\bDATASOURCE\b'
     INTEGRATION = r'\bINTEGRATION\b'
     INTEGRATIONS = r'\bINTEGRATIONS\b'
     PUBLICATION = r'\bPUBLICATION\b'
@@ -83,6 +85,7 @@ class MindsDBLexer(Lexer):
     EXPLAIN = r'\bEXPLAIN\b'
     ALTER = r'\bALTER\b'
 
+    DESCRIBE = r'\bDESCRIBE\b'
     # SHOW
 
     SHOW = r'\bSHOW\b'
@@ -103,6 +106,7 @@ class MindsDBLexer(Lexer):
     ENGINES = r'\bENGINES\b'
     CHARSET = r'\bCHARSET\b'
     COLLATION = r'\bCOLLATION\b'
+    PLUGINS = r'\bPLUGINS\b'
 
 
     # SELECT
