@@ -9,6 +9,7 @@ from mindsdb_sql.parser.dialects.mindsdb.create_view import CreateView
 from mindsdb_sql.parser.dialects.mindsdb.latest import Latest
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.dialects.mindsdb.lexer import MindsDBLexer
+from mindsdb_sql.parser.dialects.mindsdb.retrain_predictor import RetrainPredictor
 from mindsdb_sql.utils import ensure_select_keyword_order, JoinType
 
 
@@ -31,10 +32,12 @@ class MindsDBParser(Parser):
        'explain',
        'set',
        'use',
+       'describe',
        'create_predictor',
        'create_integration',
        'create_view',
        'drop_predictor',
+       'retrain_predictor',
        'drop_integration',
        'union',
        'select',
@@ -98,7 +101,7 @@ class MindsDBParser(Parser):
 
     @_('WHERE',
        'FROM',
-       'LIKE', )
+       'LIKE')
     def show_condition_token(self, p):
         return p[0]
 
@@ -107,6 +110,7 @@ class MindsDBParser(Parser):
        'TABLES',
        'FULL TABLES',
        'VARIABLES',
+       'PLUGINS',
        'SESSION VARIABLES',
        'SESSION STATUS',
        'GLOBAL VARIABLES',
@@ -129,8 +133,14 @@ class MindsDBParser(Parser):
     def show_category(self, p):
         return ' '.join([x for x in p])
 
+    # DESCRIBE
+
+    @_('DESCRIBE identifier')
+    def describe(self, p):
+        return Describe(value=p.identifier)
 
     # USE
+
     @_('USE identifier')
     def use(self, p):
         return Use(value=p.identifier)
@@ -150,6 +160,11 @@ class MindsDBParser(Parser):
     def create_view_from_table_or_nothing(self, p):
         pass
 
+    # RETRAIN PREDICTOR
+    @_('RETRAIN identifier')
+    def retrain_predictor(self, p):
+        return RetrainPredictor(p.identifier)
+
     # DROP PREDICTOR
     @_('DROP PREDICTOR identifier')
     def drop_predictor(self, p):
@@ -205,7 +220,8 @@ class MindsDBParser(Parser):
         )
 
     # CREATE INTEGRATION
-    @_('CREATE INTEGRATION ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS STRING')
+    @_('CREATE INTEGRATION ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS STRING',
+       'CREATE DATASOURCE ID WITH ENGINE EQUALS STRING COMMA PARAMETERS EQUALS STRING')
     def create_integration(self, p):
         try:
             parameters = json.loads(p.STRING1)
@@ -264,6 +280,8 @@ class MindsDBParser(Parser):
     @_('select OFFSET constant')
     def select(self, p):
         select = p.select
+        if select.offset is not None:
+            raise ParsingException(f'OFFSET already specified for this query')
         ensure_select_keyword_order(select, 'OFFSET')
         if not isinstance(p.constant.value, int):
             raise ParsingException(f'OFFSET must be an integer value, got: {p.constant.value}')
@@ -271,6 +289,16 @@ class MindsDBParser(Parser):
         select.offset = p.constant
         return select
 
+    @_('select LIMIT constant COMMA constant')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'LIMIT')
+        if not isinstance(p.constant0.value, int) or not isinstance(p.constant1.value, int):
+            raise ParsingException(f'LIMIT must have integer arguments, got: {p.constant0.value}, {p.constant1.value}')
+        select.offset = p.constant0
+        select.limit = p.constant1
+        return select
+
     @_('select LIMIT constant')
     def select(self, p):
         select = p.select
