@@ -9,7 +9,7 @@ class Variable(ASTNode):
         self.is_system_var = is_system_var
 
     def to_tree(self, *args, level=0, **kwargs):
-        alias_str = f', alias={repr(self.alias)}' if self.alias else ''
+        alias_str = f', alias={self.alias.to_tree()}' if self.alias else ''
         return indent(level) + f'Variable(value={repr(self.value)}{alias_str}, is_system_var={repr(self.is_system_var)})'
 
     def get_string(self, *args, **kwargs):
