@@ -25,6 +25,7 @@ class SQLParser(Parser):
        'explain',
        'set',
        'use',
+       'describe',
        'union',
        'select',
        )
@@ -96,6 +97,7 @@ class SQLParser(Parser):
        'TABLES',
        'FULL TABLES',
        'VARIABLES',
+       'PLUGINS',
        'SESSION VARIABLES',
        'SESSION STATUS',
        'GLOBAL VARIABLES',
@@ -111,6 +113,12 @@ class SQLParser(Parser):
     def show_category(self, p):
         return ' '.join([x for x in p])
 
+    # DESCRIBE
+
+    @_('DESCRIBE identifier')
+    def describe(self, p):
+        return Describe(value=p.identifier)
+
     # USE
 
     @_('USE identifier')
@@ -165,6 +173,8 @@ class SQLParser(Parser):
     @_('select OFFSET constant')
     def select(self, p):
         select = p.select
+        if select.offset is not None:
+            raise ParsingException(f'OFFSET already specified for this query')
         ensure_select_keyword_order(select, 'OFFSET')
         if not isinstance(p.constant.value, int):
             raise ParsingException(f'OFFSET must be an integer value, got: {p.constant.value}')
@@ -181,6 +191,16 @@ class SQLParser(Parser):
         select.limit = p.constant
         return select
 
+    @_('select LIMIT constant COMMA constant')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'LIMIT')
+        if not isinstance(p.constant0.value, int) or not isinstance(p.constant1.value, int):
+            raise ParsingException(f'LIMIT must have integer arguments, got: {p.constant0.value}, {p.constant1.value}')
+        select.offset = p.constant0
+        select.limit = p.constant1
+        return select
+
     @_('select ORDER_BY ordering_terms')
     def select(self, p):
         select = p.select
