@@ -138,6 +138,16 @@ class ApplyPredictorStep(PlanStep):
             self.references.append(dataframe)
 
 
+class ApplyTimeseriesPredictorStep(ApplyPredictorStep):
+    """Applies a mindsdb predictor on some dataframe and returns a new dataframe with predictions.
+    Accepts an additional parameter output_time_filter that specifies for which dates the predictions should be returned
+    """
+
+    def __init__(self, *args, output_time_filter=None, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.output_time_filter = output_time_filter
+
+
 class ApplyPredictorRowStep(PlanStep):
     """Applies a mindsdb predictor to one row of values and returns a dataframe of one row, the predictor."""
     def __init__(self, namespace, predictor, row_dict, *args, **kwargs):
@@ -147,6 +157,14 @@ class ApplyPredictorRowStep(PlanStep):
         self.row_dict = row_dict
 
 
+class GetPredictorColumns(PlanStep):
+    """Returns an empty dataframe of shape and columns like predictor results."""
+    def __init__(self, namespace, predictor, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.namespace = namespace
+        self.predictor = predictor
+
+
 class MapReduceStep(PlanStep):
     """Applies a step for each value in a list, and then reduces results to a single dataframe"""
     def __init__(self, values, step, reduce, *args, **kwargs):
